Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1736)

Unified Diff: chrome/browser/metrics/chrome_metrics_service_client.h

Issue 2344343002: Wire in postmortem report collection (Closed)
Patch Set: Merge Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/metrics/chrome_metrics_service_client.h
diff --git a/chrome/browser/metrics/chrome_metrics_service_client.h b/chrome/browser/metrics/chrome_metrics_service_client.h
index 600fa388d297ae188c1ce2a9473fc81a201567fc..2e625b3d40b4574e4ef1ec40b34c91b6082801a7 100644
--- a/chrome/browser/metrics/chrome_metrics_service_client.h
+++ b/chrome/browser/metrics/chrome_metrics_service_client.h
@@ -33,6 +33,10 @@ class PrefService;
class SigninStatusMetricsProvider;
#endif
+namespace browser_watcher {
+class WatcherMetricsProviderWin;
+} // namespace browser_watcher
+
namespace metrics {
class DriveMetricsProvider;
class MetricsService;
@@ -109,10 +113,14 @@ class ChromeMetricsServiceClient
// init task by loading drive metrics.
void OnInitTaskGotAntiVirusData();
// Called after the drive metrics init task has been completed that continues
// the init task by loading profiler data.
void OnInitTaskGotDriveMetrics();
+ // Called after the postmortem report collection task has been completed to
+ // continue the init task by loading profiler data.
+ void OnInitTaskCollectedPostmortemReports();
+
// Returns true iff profiler data should be included in the next metrics log.
// NOTE: This method is probabilistic and also updates internal state as a
// side-effect when called, so it should only be called once per log.
@@ -195,6 +203,10 @@ class ChromeMetricsServiceClient
// MetricsService. Has the same lifetime as |metrics_service_|.
GoogleUpdateMetricsProviderWin* google_update_metrics_provider_;
+ // The WatcherMetricsProviderWin instance that was registered with
+ // MetricsService. Has the same lifetime as |metrics_service_|.
+ browser_watcher::WatcherMetricsProviderWin* watcher_metrics_provider_;
+
// The AntiVirusMetricsProvider instance that was registered with
// MetricsService. Has the same lifetime as |metrics_service_|.
AntiVirusMetricsProvider* antivirus_metrics_provider_;
@@ -109,10 +113,14 @@ class ChromeMetricsServiceClient
// init task by loading drive metrics.
void OnInitTaskGotAntiVirusData();
- // Called after the drive metrics init task has been completed that continues
- // the init task by loading profiler data.
+ // Called after the drive metrics init task has been completed to continue
+ // the init task by optionally collecting postmortem reports.
void OnInitTaskGotDriveMetrics();
« no previous file with comments | « chrome/browser/chrome_browser_field_trials_desktop.cc ('k') | chrome/browser/metrics/chrome_metrics_service_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698